@@ -1,16 +1,16 @@
 ######################################################################
-# setting.inc.cgi - This is PyukiWiki, yet another Wiki clone.
-# $Id: setting.inc.pl,v 1.33 2007/07/15 07:40:09 papu Exp $
+# setting.inc.pl - This is PyukiWiki, yet another Wiki clone.
+# $Id: setting.inc.pl,v 1.397 2012/01/31 10:11:55 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# "PyukiWiki" version 0.2.0-p1 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2012 Nekyo
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -20,20 +20,21 @@
 # To use this plugin, rename to 'setting.inc.cgi'
 ######################################################################
 
-# Initlize
+# Initlize											# comment
 
 %::setting_cookie;
-$::setting_cookie="PyukiWikiSetting_"
-				. length($::basepath);
+$::setting_cookie="PWS_"
+				. &dbmname($::basepath);
 %::name_cookie;
-$::name_cookie="PyukiWikiUserName_"
-				. length($::basepath);
+$::name_cookie="PWU_"
+				. &dbmname($::basepath);
 
 sub plugin_setting_init {
 	&exec_explugin_sub("lang");
+	&exec_explugin_sub("urlhack");
 	if($::navi{"setting_url"} eq '') {
 		push(@::addnavi,"setting:help");
-		$::navi{"setting_url"}="$::script?cmd=setting&amp;refer=@{[&encode($::form{refer} eq '' ? $::form{mypage} : $::form{refer})]}";
+		$::navi{"setting_url"}="$::script?cmd=setting&amp;mypage=@{[&encode($::form{mypage} ne '' ? $::form{mypage} : $::form{refer})]}";
 		$::navi{"setting_name"}=$::resource{"settingbutton"};
 		$::navi{"setting_type"}="plugin";
 	}
@@ -60,21 +61,30 @@ sub plugin_setting_setting {
 	if($::setting_cookie{style} ne '') {
 		my $style=$::setting_cookie{style};
 		if($style!~/\//) {
-			my $push=$::skin_name;
+#			my $push=$::skin_name;			# comment
 			$::skin_name=$style;
 			&skin_init;
-			$::skin_name=$push;
+#			$::skin_name=$push;				# comment
 		}
 	}
 	if($::setting_cookie{fontsize}+0 > 0) {
 		$::IN_HEAD.=<<EOM
 <style type="text/css"><!--
-#body {
-	font-size: @{[$::setting_cookie{fontsize} eq 1 ? '120' : '80']}%;
-}
+#body{font-size:@{[$::setting_cookie{fontsize} eq 1 ? '120' : '90']}%;}
 //--></style>
 EOM
 	}
+
+	my $escapeoff=0;
+	if($::use_escapeoff > 0) {
+		if(defined($::setting_cookie{escapeoff})) {
+			$escapeoff=$::setting_cookie{escapeoff}+0;
+		} else {
+			$escapeoff=$::use_escapeoff+0;
+		}
+		&escapeoff if($escapeoff > 0);
+		$::escapeoff_exec = 1;
+	}
 }
 1;
 __DATA__
@@ -82,7 +92,7 @@ sub plugin_setting_setup {
 	return(
 	'ja'=>'cookieФWikiɽ򤹤',
 	'en'=>'Setup of Wiki is carried out to cookie.',
-	'url'=>'http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Admin/setting/'
+	'url'=>'http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Admin/setting/'
 	);
 __END__
 
@@ -100,35 +110,37 @@ This is plugin/setting.inc.pl 's sub plugin, look plugin document.
 
 =item PyukiWiki/Plugin/Admin/setting
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Admin/setting/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/ExPlugin/punyurl/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/lib/setting.inc.pl>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/setting.inc.pl?view=log>
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/setting.inc.pl>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/lib/setting.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/setting.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/setting.inc.pl?view=log>
 
 =back
 
 =head1 AUTHOR
 
-=over 4
-
 =item Nanami
 
-L<http://lineage.netgamers.jp/> etc...
+L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =head1 LICENSE
 
-Copyright (C) 2005-2007 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2007 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
