@@ -1,16 +1,16 @@
 ######################################################################
 # alias.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: alias.inc.pl,v 1.35 2010/12/14 22:20:00 papu Exp $
+# $Id: alias.inc.pl,v 1.380 2012/01/31 10:11:58 papu Exp $
 #
-# "PyukiWiki" version 0.1.8 $$
+# "PyukiWiki" version 0.2.0-p1 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2010 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2010 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -28,7 +28,7 @@ $alias::loopmax=2;
 @alias::pushmypage;
 
 sub plugin_alias_convert {
-;	# no param
+	# no param											# comment
 	my($page,$usethispagetitle)=split(/,/, shift);
 	return ' ' if($::form{mypage}=~/($::MenuBar|$::SideBar|$::Header|$::Footer)$/);
 	return ' ' if($::form{cmd} ne 'read');
@@ -105,11 +105,13 @@ The number of times of the maximum of an alias is specified. A default is 2.
 
 =item PyukiWiki/Plugin/Standard/alias
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/alias/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/alias/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/alias.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/alias.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/alias.inc.pl?view=log>
 
 =back
 
@@ -123,17 +125,17 @@ L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2010 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2010 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
