@@ -1,16 +1,16 @@
 ######################################################################
 # deletecache.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: deletecache.inc.pl,v 1.22 2007/07/15 07:40:09 papu Exp $
+# $Id: deletecache.inc.pl,v 1.387 2012/01/31 10:11:58 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# "PyukiWiki" version 0.2.0-p1 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2012 Nekyo
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -18,7 +18,7 @@
 ######################################################################
 
 $deletecache::ignore_regex=q(^$|^..?$|^index|htaccess$|\..{1,3}$);
-$deletecache::nonselect_regex=q(showrss);
+$deletecache::nonselect_regex=q(showrss|bak|rel);
 
 sub plugin_deletecache_action {
 	my $body;
@@ -68,7 +68,7 @@ sub deletecache_list {
 	}
 	foreach my $ext(sort keys %exts) {
 		$body.=<<EOM;
-<input type="checkbox" name="delete_$ext"@{[$ext=~/$deletecache::nonselect_regex/ ? '' : " checked"]} />
+<input type="checkbox" name="delete_$ext"@{[$ext=~/$deletecache::nonselect_regex/ ? '' : ' checked="checked"']} />
 $ext ($exts{$ext}$::resource{deletecache_plugin_files})<br />
 EOM
 	}
@@ -124,15 +124,15 @@ However, it lists files do not delete.
 
 =item index.html
 
- 
+
 
 =item .htaccess
 
- 
+
 
 =item File of extention is three of less characters.
 
- 
+
 
 =back
 
@@ -142,11 +142,13 @@ However, it lists files do not delete.
 
 =item PyukiWiki/Plugin/Admin/deletecache
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Admin/deletecache/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Admin/deletecache/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/deletecache.inc.pl>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/deletecache.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/deletecache.inc.pl?view=log>
 
 =back
 
@@ -156,21 +158,21 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin
 
 =item Nanami
 
-L<http://lineage.netgamers.jp/> etc...
+L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2007 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2007 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
