@@ -1,16 +1,16 @@
 ######################################################################
 # help.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: help.inc.pl,v 1.40 2011/01/25 03:11:15 papu Exp $
+# $Id: help.inc.pl,v 1.381 2012/01/31 10:11:58 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p2 $$
+# "PyukiWiki" version 0.2.0-p1 $$
 # Author: Nanami http://nanakochi.daiba.cx/
-# Copyright (C) 2004-2011 by Nekyo.
+# Copyright (C) 2004-2012 Nekyo
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2011 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -22,7 +22,7 @@ sub plugin_help_action {
 	if(!&is_readable($::form{mypage})) {
 		&print_error($::resource{auth_readfobidden});
 	}
-	# 2005.11.2 pochi: ҏW\
+	# 2005.11.2 pochi: ҏW\				# comment
 	&plugin_help_skinex($::form{mypage}, &text_to_html($::database{$::form{mypage}}, mypage=>$::form{mypage}), 2, @_);
 	&close_db;
 	exit;
@@ -45,8 +45,12 @@ sub plugin_help_skinex {
 	}
 	&makenavigator($page,$is_page,$editable,$admineditable);
 
-	$::IN_HEAD=&meta_robots($::form{cmd},$page,$body) . $::IN_HEAD;
-	$::HTTP_HEADER=&http_header("Content-type: text/html; charset=$::charset", $::HTTP_HEADER);
+	$::IN_HEAD.=&meta_robots($::form{cmd},$page,$body);
+	my $output_mime = $::htmlmode eq "xhtml11"
+		&& $ENV{'HTTP_ACCEPT'}=~ m!application/xhtml\+xml!
+		&& &is_no_xhtml(1) eq 0
+		? 'application/xhtml+xml' : 'text/html';
+	$::HTTP_HEADER=&http_header("Content-type: $output_mime; charset=$::charset", $::HTTP_HEADER);
 	require $::skin_file;
 	my $body=&skin($page, $body, $is_page, $bodyclass, $editable, $admineditable, $::basehref);
 	$body=&_db($body);
@@ -78,11 +82,13 @@ Display help page
 
 =item PyukiWiki/Plugin/Standard/help
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/help/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/help/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/help.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/help.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/help.inc.pl?view=log>
 
 =back
 
@@ -96,17 +102,17 @@ L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2011 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2011 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
