@@ -1,16 +1,16 @@
 ######################################################################
 # now.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: now.inc.pl,v 1.25 2006/03/17 14:00:10 papu Exp $
+# $Id: now.inc.pl,v 1.398 2012/01/31 10:11:58 papu Exp $
 #
-# "PyukiWiki" version 0.1.6 $$
-# Author: Nekyo
-# Copyright (C) 2004-2006 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2006 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# "PyukiWiki" version 0.2.0-p1 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2012 Nekyo
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -18,7 +18,6 @@
 ######################################################################
 
 use strict;
-use Time::Local;
 
 sub plugin_now_convert {
 	return &plugin_now_inline(@_);
@@ -93,33 +92,19 @@ Specification date and time. It becomes a date on the day at the time of an abbr
 
 =back
 
-=head1 SAMPLES
-
-Date format samples
-
-=over 4
-
-=item &date(Y-n-j[D] H:m:S,2006/1/1 22:15:32)
-
-2006-1-1[Sun] 22:15:32
-
-=item &date(y/m/J H:m:S,2006/1/1 22:15:32)
-
-06/01/01 22:15:32
-
-=back
-
 =head1 SEE ALSO
 
 =over 4
 
 =item PyukiWiki/Plugin/Standard/now
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/now/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/now/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/now.inc.pl>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/now.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/now.inc.pl?view=log>
 
 =back
 
@@ -129,21 +114,21 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin
 
 =item Nanami
 
-L<http://lineage.netgamers.jp/> etc...
+L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2006 by Nanami.
+Copyright (C) 2005-2012 by Nanami.
 
-Copyright (C) 2005-2006 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
