@@ -1,16 +1,16 @@
 ######################################################################
 # popular.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: popular.inc.pl,v 1.53 2007/07/15 07:40:09 papu Exp $
+# $Id: popular.inc.pl,v 1.137 2011/12/31 13:06:11 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
+# "PyukiWiki" version 0.2.0 $$
 # Author: YashiganiModoki
 #         http://hpcgi1.nifty.com/it2f/wikinger/pyukiwiki.cgi
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2004-2012 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
 # License: GPL2 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
@@ -24,7 +24,7 @@
 ######################################################################
 # Ȥ
 #
-# #popular(10(),FrontPage|MenuBar,[total/today/yesterday...])
+# #popular(10(),FrontPage|MenuBar,[total/today/yesterday...],[notitle])
 #
 # ɽ
 # оݥڡоݳΥڡɽǵҤ
@@ -32,20 +32,23 @@
 #   $::CountView=2ǤСʲѤǤޤ
 #   week - ι
 #   lastweek - 轵ι
+# notitleʸꤹȥȥ뤬ɽʤʤ롣
 # ʤpopurarѤȡưŪpopular.inc.pl󥯥롼
 # ޤ
 ######################################################################
 
-use strict;
-use Nana::Cache;
-
 # åݻ(20ʬ)
 $popular::cache_expire=20*60
 	if(!defined($popular::cache_expire));
 
+######################################################################
+
+use strict;
+use Nana::Cache;
+
 sub plugin_popular_convert {
 	my $argv = shift;
-	my ($limit, $ignore_page, $flag) = split(/,/, $argv);
+	my ($limit, $ignore_page, $flag, $notitle) = split(/,/, $argv);
 
 	return qq(<div class="error">counter.inc.pl can't require</div>)
 		if (&exist_plugin("counter") ne 1);
@@ -101,8 +104,10 @@ sub plugin_popular_convert {
 			$out =  '<ul class="popular_list">' . $out . '</ul>';
 		}
 
-		if ($::resource{"popular_plugin_$flag\_frame"}) {
-			$out=sprintf $::resource{"popular_plugin_$flag\_frame"}, $count, $out;
+		if($notitle ne 'notitle') {
+			if ($::resource{"popular_plugin_$flag\_frame"}) {
+				$out=sprintf $::resource{"popular_plugin_$flag\_frame"}, $count, $out;
+			}
 		}
 		$cache->write($cachefile,$out);
 	}
@@ -128,7 +133,7 @@ It corresponds to v0.1.6 and popular.inc.pl by which Mr. YASIganiModoki was crea
 
 =head1 USAGE
 
- #popular(max view pages, regex of disable view page[,total|today|yesterday])
+ #popular(max view pages, regex of disable view page[,total|today|yesterday][,notitle])
 
 =over 4
 
@@ -144,6 +149,10 @@ The list of pages which are not displayed is set up with a regular expression.
 
 The display of all accesses, today's display, and yesterday's display are set up. Default is all accesses.
 
+=item notitle
+
+No display popular title
+
 =back
 
 =head1 SEE ALSO
@@ -152,11 +161,11 @@ The display of all accesses, today's display, and yesterday's display are set up
 
 =item PyukiWiki/Plugin/Standard/popular
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/popular/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/popular/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/popular.inc.pl>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/popular.inc.pl?view=log>
 
 =item PyukiWiki/Plugin/popular
 
@@ -170,29 +179,16 @@ L<http://hpcgi1.nifty.com/it2f/wikinger/pyukiwiki.cgi?PyukiWiki%2f%a5%d7%a5%e9%a
 
 =over 4
 
-=item Nanami
 
-L<http://lineage.netgamers.jp/> etc...
-
-=item YashiganiModoki
-
-L<http://hpcgi1.nifty.com/it2f/wikinger/pyukiwiki.cgi>
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2004-2007 by YashiganiModoki.
 
-Copyright (C) 2005-2007 by PyukiWiki Developers Team
-
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
-
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
 
 =cut
