@@ -1,16 +1,16 @@
 ######################################################################
 # rename.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: rename.inc.pl,v 1.55 2007/07/15 07:40:09 papu Exp $
+# $Id: rename.inc.pl,v 1.501 2012/03/18 11:23:51 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
+# "PyukiWiki" ver 0.2.0-p3 $$
 # Author: Junichi http://www.re-birth.com/
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2004-2012 Nekyo
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
-# License: GPL2 and/or Artistic or each later version
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
+# License: GPL3 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -26,8 +26,8 @@
 
 use constant PLUGIN_RENAME_LOGPAGE => ':RenameLog';
 
-# %_rename_messages is deleted, moved to ./resource/rename.??.txt
-# by nanami
+# %_rename_messages is deleted, moved to ./resource/rename.??.txt	# comment
+# by nanami															# comment
 
 sub plugin_rename_action {
 
@@ -62,7 +62,7 @@ sub plugin_rename_action {
 
 		return &plugin_rename_regex(\@arr0, \@arr1);
 	} else {
-		#  $method eq 'page'
+		#  $method eq 'page'									# comment
 		$page  = &plugin_rename_getvar('page');
 		$refer = &plugin_rename_getvar('refer');
 
@@ -83,7 +83,7 @@ sub plugin_rename_action {
 }
 
 
-#  ѿ
+#  ѿ												# comment
 sub plugin_rename_getvar {
 	my ($key) = @_;
 
@@ -91,7 +91,7 @@ sub plugin_rename_getvar {
 	return isset($vars[$key]) ? $vars[$key] : '';
 }
 
-#  顼å
+#  顼å										# comment
 sub plugin_rename_err {
 	my ($err,$page) = @_;
 
@@ -111,7 +111,7 @@ sub plugin_rename_err {
 	return $msg;
 }
 
-# ʳ:ڡ̾ޤɽ
+# ʳ:ڡ̾ޤɽ							# comment
 sub plugin_rename_phase1 {
 	my ($err, $page) = @_;
 
@@ -154,7 +154,7 @@ EOD
 	return %ret;
 }
 
-# ʳ:̾
+# ʳ:̾									# comment
 sub plugin_rename_phase2 {
 	my $err = shift;
 
@@ -205,7 +205,7 @@ EOD
 	return %ret;
 }
 
-# ڡ̾ȴϢڡ󤷡phase3
+# ڡ̾ȴϢڡ󤷡phase3				# comment
 sub plugin_rename_refer {
 	$page  = &plugin_rename_getvar('page');
 	$refer = &plugin_rename_getvar('refer');
@@ -218,16 +218,16 @@ sub plugin_rename_refer {
 		$to   = &strip_bracket($page);
 
 		foreach $_page (&plugin_rename_getrelated($refer)) {
-			# $_pageִ̤$_page_to
+			# $_pageִ̤$_page_to				# comment
 			($_page_to = $_page)=~s/$from/$to/;
 			$pages{&dbmname($_page)} = &dbmname($_page_to);
 		}
 	}
-	# λ%pagesˤϡڡ̾ => ڡ̾ ȤǡäƤ
+	# λ%pagesˤϡڡ̾ => ڡ̾ ȤǡäƤ	# comment
 	return &plugin_rename_phase3(%pages);
 }
 
-# ɽǥڡִ
+# ɽǥڡִ									# comment
 sub plugin_rename_regex {
 	my ($arr_from, $arr_to) = @_;
 
@@ -239,7 +239,7 @@ sub plugin_rename_regex {
 	}
 
 	if (@exists > 0) {
-		# ִΥڡ̾Ǥ¸ߤ
+		# ִΥڡ̾Ǥ¸ߤ				# comment
 		return &plugin_rename_phase1('already', \@exists);
 	} else {
 		%pages = ();
@@ -269,12 +269,12 @@ sub plugin_rename_phase3 {
 	}
 
 	$pass = &plugin_rename_getvar('mypassword');
-#	v0.1.6 changed by nanami
-#	if ($pass ne '' && &valid_password($pass)) {
+#	v0.1.6 changed by nanami							# comment
+#	if ($pass ne '' && &valid_password($pass)) {		# comment
 	if (&plugin_rename_getvar('exec') eq 1) {
 		return &plugin_rename_proceed(\%pages, \%files, \%exists);
-#	} elsif ($pass ne '') {
-#		$msg = &plugin_rename_err('adminpass');
+#	} elsif ($pass ne '') {								# comment
+#		$msg = &plugin_rename_err('adminpass');			# comment
 	}
 
 	$method = &plugin_rename_getvar('method');
@@ -325,7 +325,7 @@ sub plugin_rename_phase3 {
 
 	%ret = ();
 	$ret{'msg'} = "\t$::resource{'rename_plugin_msg_title'}";
-	# v0.1.6 changed by nanami
+	# v0.1.6 changed by nanami									# comment
 	$ret{'body'} = <<EOD;
 <p>$msg</p>
 <table><tr><td>
@@ -337,13 +337,14 @@ sub plugin_rename_phase3 {
   <input type="hidden" name="cmd" value="rename" />
   <input type="hidden" name="exec" value="1" />
   $input
-  <input type="submit" value="@{[$::resource{'rename_plugin_btn_submit'}]}" />
+  <input type="submit" value="$::resource{'rename_plugin_btn_submit'}" />
  </div>
 </form>
+</td></tr>
 </table>
 EOD
-#  @{[$::resource{'rename_plugin_msg_adminpass'}]}
-#  <input type="password" name="mypassword" value="" />
+#  @{[$::resource{'rename_plugin_msg_adminpass'}]}				# comment
+#  <input type="password" name="mypassword" value="" />			# comment
 
 	$ret{'body'} .= '<ul>' . "\n";
 	foreach $old (reverse sort keys %pages) {
@@ -357,19 +358,20 @@ EOD
 }
 
 
-# оݤΥեξʸեѥեѥˤΰ
+# оݤΥեξʸեѥեѥˤΰ	# comment
 sub plugin_rename_get_files {
 	my (%pages) = @_;
 
 	my %files = ();
-	@dirs  = ($::diff_dir, $::data_dir);
+	@dirs  = ($::diff_dir, $::data_dir, $::counter_dir, $::info_dir);#compact
+	@dirs  = ($::diff_dir, $::data_dir, $::counter_dir, $::info_dir, $::backup_dir);#nocompact
 	if (&exist_plugin('attach')){
 		push (@dirs, $::upload_dir);
 	}
 	if (&exist_plugin('rename')) {
 		push (@dirs, $::rename_dir);
 	}
-	#  and more ...
+	#  and more ...										# comment
 
 	foreach $path (@dirs) {
 		opendir(DH,$path);
@@ -377,7 +379,7 @@ sub plugin_rename_get_files {
 			next;
 		}
 
-		# PyukiWikiΥǥ쥯ȥǺǸ夬/Ǥʤղä롣
+		# PyukiWikiΥǥ쥯ȥǺǸ夬/Ǥʤղä롣	# comment
 		if($path=~/.*[^\/]$/) {
 			$path .= '/';
 		}
@@ -386,21 +388,21 @@ sub plugin_rename_get_files {
 			if ($file eq '.' || $file eq '..'){
 				next;
 			}
-			
+
 			foreach $from (keys %pages) {
 
 				$to = $pages{$from};
 
-				# 󥿡ξϡ٥ǥɤ&encode()롣
-				if($path=~/$::rename_dir/) {
-					$from = &encode(&dbmname_decode($from));
-					$to = &encode(&dbmname_decode($to));
-				}
+#				# 󥿡ξϡ٥ǥɤ&encode()롣	# comment
+#				if($path=~/$::rename_dir/) {						# comment
+#					$from = &encode(&dbmname_decode($from));		# comment
+#					$to = &encode(&dbmname_decode($to));			# comment
+#				}													# comment
 
-				# /  \/ ִ
+				# /  \/ ִ									# comment
 				$from=~s/\//\\\//g;
 
-				# ѥκǸ ([._].+) PyukiǤפȻפ
+				# ѥκǸ ([._].+) PyukiǤפȻפ	# comment
 				my $pattern = '^' . $from . '([._].+)$';
 				if (not $file=~/$pattern/) {
 					next;
@@ -415,11 +417,11 @@ sub plugin_rename_get_files {
 	return %files;
 }
 
-# 
+# 															# comment
 sub plugin_rename_proceed {
 	my ($pages, $files, $exists) = @_;
 
-	# ѥ᡼exist1()Ǥʤ¸ߤڡоݤϤ
+	# ѥ᡼exist1()Ǥʤ¸ߤڡоݤϤ	# comment
 	if (&plugin_rename_getvar('exist') ne '1') {
 
 		foreach my $key (keys %$exists) {
@@ -428,25 +430,25 @@ sub plugin_rename_proceed {
 		}
 	}
 
-#	set_time_limit(0);
+#	set_time_limit(0);												# comment
 	foreach $page(keys %$files) {
 		$arr = $files->{$page};
 
 		foreach $old (keys %$arr) {
 			$new = $arr->{$old};
 
-			# ¸ߤƤơġͤǼƤ $new
+			# ¸ߤƤơġͤǼƤ $new	# comment
 			if (exists($exists->{$page}{$old}) && defined($exists->{$page}{$old})){
 				unlink($new);
 			}
 			rename($old, $new);
-			#  linkǡ١򹹿 BugTrack/327 arino
-#			links_update($old);
-#			links_update($new);
+			#  linkǡ١򹹿 BugTrack/327 arino		# comment
+#			links_update($old);										# comment
+#			links_update($new);										# comment
 		}
 	}
 
-	# ڡΥǡơɵ
+	# ڡΥǡơɵ							# comment
 	$postdata = $::database{PLUGIN_RENAME_LOGPAGE};
 	$postdata .= '*' . &date($::date_format . " " . $::time_format . " (D)") . "\n";
 	if (&plugin_rename_getvar('method') eq 'regex') {
@@ -481,23 +483,23 @@ sub plugin_rename_proceed {
 	}
 
 
-	#  ξͤϥåʤ
+	#  ξͤϥåʤ								# comment
 
-	#  եν񤭹
+	#  եν񤭹										# comment
 	$::database{::PLUGIN_RENAME_LOGPAGE} = $postdata;
 	&close_db();
 
-	# 쥯
+	# 쥯												# comment
 	$page = &plugin_rename_getvar('page');
 	if ($page eq '') {
 		$page = PLUGIN_RENAME_LOGPAGE;
 	}
 
-#	pkwk_headers_sent();
-#	header('Location: ' . get_script_uri() . '?' . rawurlencode($page));
-#	v0.1.6 changed by nanami
-#	print "Location: $::script?@{[&encode($page)]}\n\n";
-#	exit;
+#	pkwk_headers_sent();										# comment
+#	header('Location: ' . get_script_uri() . '?' . rawurlencode($page));	# comment
+#	v0.1.6 changed by nanami									# comment
+#	print "Location: $::script?@{[&encode($page)]}\n\n";		# comment
+#	exit;														# comment
 	print &http_header(
 		"Status: 302",
 		"Location: $::basehref?@{[&encode($page)]}"
@@ -526,15 +528,15 @@ sub plugin_rename_getrelated {
 }
 
 
-# ¸ߤڡ٤ƤΥץ
+# ¸ߤڡ٤ƤΥץ							# comment
 sub plugin_rename_getselecttag {
 	my ($page) = @_;
 
 	my %pages = ();
 	foreach $_page (sort keys %::database) {
-#		if ($_page == $whatsnew) {
-#			next;
-#		}
+#		if ($_page == $whatsnew) {									# comment
+#			next;													# comment
+#		}															# comment
 
 		$selected = ($_page eq $page) ? ' selected' : '';
 		$s_page = &htmlspecialchars($_page);
@@ -556,14 +558,14 @@ EOD
 
 }
 
-# ڡ̾Υǥɡ<==> dbmname
+# ڡ̾Υǥɡ<==> dbmname									# comment
 sub dbmname_decode {
 	my $name = shift;
 	return ($name =~/^[0-9a-f]+$/i) ? pack('H*', $name ) : $name ;
 }
 
-# [[ ]] 
-# from PukiWiki lib/func.php
+# [[ ]] 													# comment
+# from PukiWiki lib/func.php										# comment
 sub strip_bracket {
 	my ($str) = @_;
 
@@ -574,36 +576,36 @@ sub strip_bracket {
 	}
 }
 
-# from PukiWiki lib/make_link.php
-# ʬǤ
+# from PukiWiki lib/make_link.php									# comment
+# ʬǤ													# comment
 sub make_pagelink {
 	my $page = shift;
 	return qq|<a href="$::script?@{[&encode($page)]}">$page</a>|;
 }
 
-# ڡ̾Ȥɤå
-# from PukiWiki lib/func.php
+# ڡ̾Ȥɤå								# comment
+# from PukiWiki lib/func.php										# comment
 sub is_pagename {
 	my ($str) = @_;
 	my $is_pagename= (not &is_interwiki($str) &&
 						$str=~/^(?!\/)$bracket_name$(?<!\/$)/ &&
 						$str=~/(^|\/)\.{1,2}(\/|$)/);
-	# SOURCE_ENCODING˳Ͼά
+	# SOURCE_ENCODING˳Ͼά							# comment
 	return $is_pagename;
 }
 
-# from PukiWiki lib/func.php
+# from PukiWiki lib/func.php										# comment
 sub is_interwiki {
 	my ($str) = @_;
 
-	# ȽˤϡPyukiWiki$interwiki_name2
+	# ȽˤϡPyukiWiki$interwiki_name2				# comment
 
-	# from PukiWiki lib/init.php
-	# my $InterWikiName = '(\[\[)?((?:(?!\s|:|\]\]).)+):(.+)(?(1)\]\])';
+	# from PukiWiki lib/init.php									# comment
+	# my $InterWikiName = '(\[\[)?((?:(?!\s|:|\]\]).)+):(.+)(?(1)\]\])';	# comment
 
-	# from PyukiWiki index.cgi
-	# my $interwiki_name = '([^:]+):([^:].*)';
-	# my $interwiki_name2 = '([^:]+):([^:#].*?)(#.*)?';
+	# from PyukiWiki index.cgi										# comment
+	# my $interwiki_name = '([^:]+):([^:].*)';						# comment
+	# my $interwiki_name2 = '([^:]+):([^:#].*?)(#.*)?';				# comment
 
 	return $str=~/^$interwiki_name$/;
 }
@@ -638,11 +640,13 @@ Updating is not applied to recent.
 
 =over 4
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Admin/rename/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Admin/rename/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/rename.inc.pl>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/rename.inc.pl?view=log>
+
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel-UTF8/plugin/rename.inc.pl?view=log>
 
 =item Site manufacture/PyukiWiki/Plugin/Rename
 
@@ -662,17 +666,17 @@ L<http://www.re-birth.com/>
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2005-2007 by Junichi.
+Copyright (C) 2005-2012 by Junichi.
 
-Copyright (C) 2005-2007 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
-License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+License is GNU GENERAL PUBLIC LICENSE 3 and/or Artistic 1 or each later version.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
