@@ -1,15 +1,15 @@
 ######################################################################
 # ruby.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: ruby.inc.pl,v 1.77 2010/12/29 06:21:06 papu Exp $
+# $Id: ruby.inc.pl,v 1.338 2011/12/31 13:06:11 papu Exp $
 #
-# "PyukiWiki" version 0.1.8-p1 $$
+# "PyukiWiki" version 0.2.0 $$
 # Author: Nekyo
-# Copyright (C) 2004-2010 by Nekyo.
+# Copyright (C) 2004-2012 by Nekyo.
 # http://nekyo.qp.land.to/
-# Copyright (C) 2005-2010 PyukiWiki Developers Team
-# http://pyukiwiki.sourceforge.jp/
+# Copyright (C) 2005-2012 PyukiWiki Developers Team
+# http://pyukiwiki.sfjp.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
-# Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
+# Powerd by PukiWiki http://pukiwiki.sfjp.jp/
 # License: GPL2 and/or Artistic or each later version
 #
 # This program is free software; you can redistribute it and/or
@@ -48,11 +48,11 @@ A kana of ruby set as a character string.
 
 =item PyukiWiki/Plugin/Standard/ruby
 
-L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/ruby/>
+L<http://pyukiwiki.sfjp.jp/PyukiWiki/Plugin/Standard/ruby/>
 
 =item PyukiWiki CVS
 
-L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/ruby.inc.pl?view=log>
+L<http://sfjp.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/ruby.inc.pl?view=log>
 
 =back
 
@@ -66,15 +66,15 @@ L<http://nekyo.qp.land.to/>
 
 =item PyukiWiki Developers Team
 
-L<http://pyukiwiki.sourceforge.jp/>
+L<http://pyukiwiki.sfjp.jp/>
 
 =back
 
 =head1 LICENSE
 
-Copyright (C) 2004-2010 by Nekyo.
+Copyright (C) 2004-2012 by Nekyo.
 
-Copyright (C) 2005-2010 by PyukiWiki Developers Team
+Copyright (C) 2005-2012 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
